Index: CMake/export.cmake
===================================================================
--- CMake/export.cmake	(revision 10728)
+++ CMake/export.cmake	(working copy)
@@ -50,9 +50,12 @@
 
 configure_file(
    ${FLTK_SOURCE_DIR}/CMake/FLTKConfig.cmake.in
-   ${FLTK_BINARY_DIR}/FLTKConfig.cmake
+   ${FLTK_BINARY_DIR}/${FLTK_REGISTRY_NAME}Config.cmake
    @ONLY
 )
+if(FLTK_USE_CMAKE_REGISTRY)
+	export(PACKAGE ${FLTK_REGISTRY_NAME})
+endif(FLTK_USE_CMAKE_REGISTRY)
 
 # generate UseFLTK.cmake for build directory use
 configure_file(
Index: CMake/options.cmake
===================================================================
--- CMake/options.cmake	(revision 10728)
+++ CMake/options.cmake	(working copy)
@@ -20,6 +20,24 @@
 #######################################################################
 # options
 #######################################################################
+# package registry not available prior to CMake 2.8.5
+if(NOT CMAKE_VERSION VERSION_LESS 2.8.5)
+	option(FLTK_USE_CMAKE_REGISTRY "save location in CMake registry" ON)
+	set(FLTK_REGISTRY_NAME "FLTK"
+	CACHE STRING
+	"the name this FLTK instance is known by"
+	)
+else()
+	set(FLTK_USE_CMAKE_REGISTRY OFF)
+	set(FLTK_REGISTRY_NAME "FLTK")
+	mark_as_advanced(FLTK_USE_CMAKE_REGISTRY FLTK_REGISTRY_NAME)
+endif(NOT CMAKE_VERSION VERSION_LESS 2.8.5)
+# we can't have a blank registry name
+if(NOT FLTK_REGISTRY_NAME)
+	set(FLTK_REGISTRY_NAME "FLTK")
+endif(NOT FLTK_REGISTRY_NAME)
+
+#######################################################################
 set(OPTION_OPTIM ""
    CACHE STRING
    "custom optimization flags"
Index: README.CMake.txt
===================================================================
--- README.CMake.txt	(revision 10728)
+++ README.CMake.txt	(working copy)
@@ -248,6 +248,16 @@
 
 The set(FLTK_DIR ...) command is a superhint to the find_package command.
 This is very useful if you don't install or have a non-standard install.
+
+In the likely case that you use CMake 2.8.5 or later, you have a better option.
+Build, but don't install FLTK and use the FLTK_USE_CMAKE_REGISTRY option.
+Just use the FLTK_REGISTRY_NAME in the find_package.  No neeed to set FLTK_DIR.
+You can even have multiple builds, each with different FLTK_REGISTRY_NAME.
+CMake will keep track of where they are.  FLTK-debug and FLTK-release are 
+two obvious choices, but you can have as many as you want, all easily found.
+You can even make it an option in your CMakeLists.txt for your project
+and set which FLTK build you use when you configure your project.
+
 The find_package command tells CMake to find the package FLTK, REQUIRED
 means that it is an error if it's not found.  NO_MODULE tells it to search
 only for the FLTKConfig file, not using the FindFLTK.cmake supplied with
